#
# spec file for package python3-twine
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-twine
Version:        1.7.4
Release:        1.2
Summary:        Collection of utilities for interacting with PyPI
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/pypa/twine
Source:         https://files.pythonhosted.org/packages/source/t/twine/twine-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python3-pkginfo
Requires:       python3-requests
Requires:       python3-requests-toolbelt
BuildArch:      noarch

%description
Twine is a utility for interacting with PyPI.

Currently it only supports uploading distributions.


Why Should I Use This?
----------------------

The biggest reason to use twine is that python setup.py upload uploads
files over plaintext. This means anytime you use it you expose your username
and password to a MITM attack. Twine uses only verified TLS to upload to PyPI
protecting your credentials from theft.

Secondly it allows you to precreate your distribution files.
python setup.py upload only allows you to upload something that you've
created in the same command invocation. This means that you cannot test the
exact file you're going to upload to PyPI to ensure that it works before
uploading it.

Finally it allows you to pre-sign your files and pass the .asc files into
the command line invocation
(twine upload twine-1.0.1.tar.gz twine-1.0.1.tar.gz.asc). This enables you
to be assured that you're typing your gpg passphrase into gpg itself and not
anything else since *you* will be the one directly executing
gpg --detach-sign -a <filename>.


Features
--------

* Verified HTTPS Connections
* Uploading doesn't require executing setup.py
* Uploading files that have already been created, allowing testing of
  distributions before release

%prep
%setup -q -n twine-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/twine %{buildroot}%{_bindir}/twine-%{py3_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/twine
ln -s -f %{_sysconfdir}/alternatives/twine %{buildroot}%{_bindir}/twine

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/twine twine %{_bindir}/twine-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove twine %{_bindir}/twine-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst
%{_bindir}/twine
%{_bindir}/twine-%{py3_ver}
%{python3_sitelib}/*
%ghost %{_sysconfdir}/alternatives/twine

%changelog
* Sat Jul  9 2016 arun@gmx.de
- update to version 1.7.4:
  * Correct a packaging error.
* Fri Jul  8 2016 arun@gmx.de
- update to version 1.7.3:
  * :bug:`195` Fix uploads to instances of pypiserver using
    "--skip-existing". We were not properly checking the return status
    code on the response after attempting an upload.
  * Do not generate traffic to Legacy PyPI unless we're uploading to
    it or uploading to Warehouse (e.g., pypi.io). This avoids the
    attempt to upload a package to the index if we can find it on
    Legacy PyPI already.
* Thu Jul  7 2016 arun@gmx.de
- update to version 1.7.2:
  * :bug:`189`, :bug:`191` Fix issue where we were checking the
    existence of packages even if the user didn't specify
  - -skip-existing.
* Wed Jul  6 2016 arun@gmx.de
- update to version 1.7.1:
  * Clint was not specified in the wheel metadata as a dependency.
* Tue Jul  5 2016 arun@gmx.de
- update to version 1.7.0:
  * :feature:`142` Support --cert and --client-cert command-line flags
    and config file options for feature parity with pip. This allows
    users to verify connections to servers other than PyPI (e.g.,
    local package repositories) with different certificates.
  * :feature:`152` Add progress bar to uploads.
  * :feature:`162` Allow --skip-existing to work for 409 status codes.
  * :feature:`167` Implement retries when the CDN in front of PyPI
    gives us a 5xx error.
  * :feature:`177` Switch Twine to upload to pypi.io instead of
    pypi.python.org.
  * :bug:`186` Allow passwords to have %%s in them.
* Mon May 16 2016 carmenbbakker@gmail.com
- specfile:
  * Added python3-requests-toolbelt as dependency
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Tue Dec 29 2015 arun@gmx.de
- update to version 1.6.5:
  * Bump requests-toolbelt version to ensure we avoid ConnectionErrors
* Thu Oct 29 2015 arun@gmx.de
- update to version 1.6.4:
  * :bug:`145` Paths with hyphens in them break the Wheel regular
    expression.
  * :bug:`146` Exception while accessing the respository key when
    raising a redirect exception.
* Tue Oct  6 2015 arun@gmx.de
- update to version 1.6.3:
  * :bug:`137`, :bug:`140` Uploading signatures was broken due to the
    pull request that added large file support via
    requests-toolbelt. This caused a 500 error on PyPI and prevented
    package and signature upload in twine 1.6.0
* Fri Oct  2 2015 arun@gmx.de
- specfile: updated url
- update to version 1.6.2:
  * Upload signatures with packages appropriately
  * As part of the refactor for the 1.6.0 release, we were using the
    wrong name to find the signature file.
  * This also uncovered a bug where if you're using twine in a
    situation where * is not expanded by your shell, we might also
    miss uploading signatures to PyPI. Both were fixed as part of
    this.
* Fri Sep 25 2015 p.drouand@gmail.com
- Initial release (version 1.6.1)
